abacusai.video_gen_model — AbacusAI documentation

# abacusai.video_gen_model

## Classes

`VideoGenModel` | Video generation model

## Module Contents

class abacusai.video_gen_model.VideoGenModel(client, displayName=None, type=None, valueType=None, optional=None, default=None, helptext=None, options={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Video generation model

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - displayName (str) – The display name for the UI component.

    - type (str) – The type of the UI component.

    - valueType (str) – The data type of the values within the UI component.

    - optional (bool) – Whether the selection of a value is optional.

    - default (str) – The default value for the video generation model.

    - helptext (str) – The helptext for the UI component.

    - options (VideoGenModelOptions) – The options of models available for video generation.

  display_name = None
  type = None
  value_type = None
  optional = None
  default = None
  helptext = None
  options
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict